==> apache-datasketches-java-6.2.0-src.zip: apache-datasketches-java-6.2.0-src/src/main/java/org/apache/datasketches/tuple/arrayofdoubles/HeapArrayOfDoublesIntersection.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.datasketches.tuple.arrayofdoubles;

/**
 * On-heap implementation of intersection set operation for tuple sketches of type
 * ArrayOfDoubles.
 */
final class HeapArrayOfDoublesIntersection extends ArrayOfDoublesIntersection {

  /**
   * Creates an instance of a HeapArrayOfDoublesIntersection with a custom update seed
   * @param numValues number of double values associated with each key
   * @param seed <a href="{@docRoot}/resources/dictionary.html#seed">See seed</a>
   */
  HeapArrayOfDoublesIntersection(final int numValues, final long seed) {
    super(numValues, seed);
  }

  @Override
  protected ArrayOfDoublesQuickSelectSketch createSketch(final int nomEntries, final int numValues, 
      final long seed) {
    return new HeapArrayOfDoublesQuickSelectSketch(nomEntries, 0, 1f, numValues, seed);
  }

}

==> apache-datasketches-java-9.0.0-src.zip: apache-datasketches-java-9.0.0-src/src/main/java/org/apache/datasketches/tuple/arrayofdoubles/HeapArrayOfDoublesIntersection.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.datasketches.tuple.arrayofdoubles;

/**
 * On-heap implementation of intersection set operation for tuple sketches of type
 * ArrayOfDoubles.
 */
final class HeapArrayOfDoublesIntersection extends ArrayOfDoublesIntersection {

  /**
   * Creates an instance of a HeapArrayOfDoublesIntersection with a custom update seed
   * @param numValues number of double values associated with each key
   * @param seed <a href="{@docRoot}/resources/dictionary.html#seed">See seed</a>
   */
  HeapArrayOfDoublesIntersection(final int numValues, final long seed) {
    super(numValues, seed);
  }

  @Override
  protected ArrayOfDoublesQuickSelectSketch createSketch(final int nomEntries, final int numValues, final long seed) {
    return new HeapArrayOfDoublesQuickSelectSketch(nomEntries, 0, 1f, numValues, seed);
  }

}
